@@ -2,10 +2,10 @@
 #
 # Module  : ObjectIdSet.pm
 # Purpose : A generic set of ontology objects.
-# License : Copyright (c) 2007, 2008 Erick Antezana. All rights reserved.
+# License : Copyright (c) 2007, 2008, 2009, 2010 by Erick Antezana. All rights reserved.
 #           This program is free software; you can redistribute it and/or
 #           modify it under the same terms as Perl itself.
-# Contact : Erick Antezana <erick.antezana@gmail.com>
+# Contact : Erick Antezana <erick.antezana -@- gmail.com>
 #
 package OBO::Util::ObjectIdSet;
 
@@ -81,7 +81,7 @@ this interface models the mathematical set abstraction.
 
 =head1 AUTHOR
 
-Erick Antezana, E<lt>erick.antezana@gmail.comE<gt>
+Erick Antezana, E<lt>erick.antezana -@- gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
