@@ -3,10 +3,10 @@
 # Script  : get_ancestor_terms.pl
 # Purpose : Collects the ancestor terms from a given term in the given OBO ontology
 # Usage   : /usr/bin/perl -w get_ancestor_terms.pl my_ontology.obo term_id > ancestors.txt
-# License : Copyright (c) 2007, 2008 Erick Antezana. All rights reserved.
+# License : Copyright (c) 2007, 2008, 2009, 2010 by Erick Antezana. All rights reserved.
 #           This program is free software; you can redistribute it and/or
 #           modify it under the same terms as Perl itself.
-# Contact : Erick Antezana <erick.antezana@gmail.com>
+# Contact : Erick Antezana <erick.antezana -@- gmail.com>
 
 =head1 NAME
 
@@ -18,7 +18,7 @@ Collects the ancestor terms from a given term in the given OBO ontology.
 
 =head1 AUTHOR
 
-Erick Antezana, E<lt>erick.antezana@gmail.comE<gt>
+Erick Antezana, E<lt>erick.antezana -@- gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
