@@ -7,11 +7,11 @@
 # Usage:
 #           perl goa2rdf.pl input_file.goa  > output_file.rdf
 #
-# License : Copyright (c) 2008 Erick Antezana. All rights reserved.
+# License : Copyright (c) 2008, 2009, 2010 by Erick Antezana. All rights reserved.
 #           This program is free software; you can redistribute it and/or
 #           modify it under the same terms as Perl itself.
 #
-# Contact : Erick Antezana <erick.antezana@gmail.com>
+# Contact : Erick Antezana <erick.antezana -@- gmail.com>
 #
 ##############################################################################
 
@@ -25,7 +25,7 @@ Generates a simple RDF graph from a given GOA file.
 
 =head1 AUTHOR
 
-Erick Antezana, E<lt>erick.antezana@gmail.comE<gt>
+Erick Antezana, E<lt>erick.antezana -@- gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
