@@ -6,7 +6,7 @@
 # License : Copyright (c) 2006, 2007, 2008, 2009, 2010 Erick Antezana. All rights reserved.
 #           This program is free software; you can redistribute it and/or
 #           modify it under the same terms as Perl itself.
-# Contact : Erick Antezana <erick.antezana@gmail.com>
+# Contact : Erick Antezana <erick.antezana -@- gmail.com>
 #
 
 =head1 NAME
@@ -20,7 +20,7 @@ Use the owl2obo.pl to get the round-trip transformation.
 
 =head1 AUTHOR
 
-Erick Antezana, E<lt>erick.antezana@gmail.comE<gt>
+Erick Antezana, E<lt>erick.antezana -@- gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -38,6 +38,8 @@ use warnings;
 
 use OBO::Parser::OBOParser;
 
-my $my_parser = OBO::Parser::OBOParser->new();
-my $ontology = $my_parser->work(shift(@ARGV));
-$ontology->export(\*STDOUT, "owl");
+my $my_parser   = OBO::Parser::OBOParser->new();
+my $ontology    = $my_parser->work(shift);
+my $url         = shift;
+my $oboinowlurl = shift;
+$ontology->export(\*STDOUT, "owl", $url, $oboinowlurl);
